@@ -36,10 +36,6 @@ from pypdf.errors import DeprecationError, PdfReadError, PdfStreamError
 
 from . import is_sublist
 
-TESTS_ROOT = Path(__file__).parent.resolve()
-PROJECT_ROOT = TESTS_ROOT.parent
-RESOURCE_ROOT = PROJECT_ROOT / "resources"
-
 
 @pytest.mark.parametrize(
     ("stream", "expected"),
@@ -334,7 +330,8 @@ def test_file_class():
     """File class can be instantiated and string representation is ok."""
     f = File(name="image.png", data=b"")
     assert str(f) == "File(name=image.png, data: 0 Byte)"
-    assert repr(f) == "File(name=image.png, data: 0 Byte, hash: 0)"
+    # hash(b"") varies between CPython and PyPy
+    assert repr(f) == f"File(name=image.png, data: 0 Byte, hash: {hash(b'')})"
 
 
 @pytest.mark.parametrize(
